"""Version information for django-affiliate-system."""

__version__ = "0.1.0a2"
__title__ = "django-affiliate-system"
__description__ = "A comprehensive Django affiliate marketing and referral tracking system"
__author__ = "Ayodeji Akenroye"
__author_email__ = "aayodeji.f@gmail.com"
__license__ = "MIT"
__url__ = "https://github.com/aayodejii/django-affiliate-system"
